# NNSVS

[![][docs-latest-img]][docs-latest-url]
[![PyPI](https://img.shields.io/pypi/v/nnsvs.svg)](https://pypi.python.org/pypi/nnsvs)
[![License](http://img.shields.io/badge/license-MIT-brightgreen.svg?style=flat)](LICENSE)
![Python CI](https://github.com/r9y9/nnsvs/workflows/Python%20CI/badge.svg)
[![Streamlit App](https://static.streamlit.io/badges/streamlit_badge_black_white.svg)](https://share.streamlit.io/r9y9/nnsvs/streamlit_demo/app.py)

[docs-latest-img]: https://img.shields.io/badge/docs-latest-blue.svg
[docs-latest-url]: https://r9y9.github.io/nnsvs/

Neural network-based singing voice synthesis library for research

